import React, { useEffect, useState } from "react";
import { useSelector } from "react-redux";
import { Outlet, useSearchParams } from "react-router-dom";
import { JobPayloadType, Reducers } from "../common/types";
import Layout from "../Layouts/Layout";

const ApplicationsLayout = () => {
  const jobs = useSelector(
    (state: Reducers) => state.common.jobs
  ) as JobPayloadType[];
  const [searchParams] = useSearchParams();
  const [job, setJob] = useState<JobPayloadType | null>();
  const jobId = searchParams.get("jobId");

  useEffect(() => {
    if (jobId) {
      const found = jobs.find((_job) => _job._id === jobId);
      setJob(found);
    }
  }, [jobId, jobs]);

  const renderSkills = (skill: string, index: number) => (
    <span className="skill" key={index}>
      {skill}
    </span>
  );

  if (!job) return <Layout title="Applications"></Layout>;
  return (
    <Layout title={job.title}>
      <div className="row">
        <div className="col-4">
          <div className="card p-4 job-preview">
            <p>
              Salary : {job.salary.min} - {job.salary.max} {job.salary.currency}{" "}
            </p>
            <p className="desc">{job.description}</p>
            <label>Primary skills</label>
            <div className="skills">{job.primarySkills.map(renderSkills)}</div>
            <label>Secondary skills</label>
            <div className="skills">
              {job.secondarySkills.map(renderSkills)}
            </div>
            <div className="mt-2">
              <label>Applicattions : </label>{" "}
              <a href={`/applications?jobId=${job._id}`}>
                ({job.applications?.length}) Candidates
              </a>
            </div>
          </div>
        </div>
        <div className="col-8">
          <Outlet context={job} />
        </div>
      </div>
    </Layout>
  );
};

export default ApplicationsLayout;
