import { put, takeLeading, call } from "redux-saga/effects";
import { ACTIONS } from "../actions";
import { APP_STATE, ApplicationPayloadType } from "../types";
import MeetingsAPI from "../apis/meetings";
import { getJobs } from "./common";
import CommonAPI from "../apis/common";

function* createMeeting({
  payload,
  success,
}: {
  type: typeof ACTIONS.CREATE_MEETING;
  payload: ApplicationPayloadType;
  success?: (roomId: string | null) => void;
}) {
  try {
    yield put({
      type: ACTIONS.SET_APP_STATE,
      payload: { state: APP_STATE.LOADING },
    });

    const data: { roomId: string } = yield call(
      MeetingsAPI.createRoom,
      payload._id
    );

    yield call(updateApplicationAction, {
      type: ACTIONS.UPDATE_APPLICATION_ACTION,
      payload: {
        applicationId: payload._id,
        update: { interview: { ...payload.interview, link: data.roomId } },
      },
    });

    yield put({
      type: ACTIONS.SET_APP_STATE,
      payload: { state: APP_STATE.SUCCESS },
    });
    success?.(data.roomId);
  } catch (error) {
    yield put({
      type: ACTIONS.SET_APP_STATE,
      payload: { state: APP_STATE.FAILED },
    });
    success?.(null);
  }
}

export function* endMeeting({
  payload,
  success,
}: {
  type: typeof ACTIONS.END_MEETING;
  payload: { application: ApplicationPayloadType; roomId: string };
  success?: () => void;
}) {
  try {
    yield put({
      type: ACTIONS.SET_APP_STATE,
      payload: { state: APP_STATE.LOADING },
    });

    // yield call(MeetingsAPI.endSession, payload.roomId);
    // yield call(MeetingsAPI.deactivateRoom, payload.roomId);

    yield put({
      type: ACTIONS.SET_APP_STATE,
      payload: { state: APP_STATE.SUCCESS },
    });
    success?.();
  } catch (error) {
    yield put({
      type: ACTIONS.SET_APP_STATE,
      payload: { state: APP_STATE.FAILED },
    });
    success?.();
  }
}

export function* updateApplication({
  payload,
  success,
}: {
  type: typeof ACTIONS.UPDATE_APPLICATION;
  payload: { applicationId: string; update: any; candidateId?: string };
  success?: () => void;
}) {
  try {
    yield put({
      type: ACTIONS.SET_APP_STATE,
      payload: { state: APP_STATE.LOADING },
    });

    const data: { success: boolean } = yield call(
      CommonAPI.updateApplication,
      payload
    );

    if (data.success) {
      yield call(getJobs, { type: ACTIONS.GET_JOBS });
    }

    yield put({
      type: ACTIONS.SET_APP_STATE,
      payload: { state: APP_STATE.SUCCESS },
    });
    success?.();
  } catch (error) {
    success?.();
    yield put({
      type: ACTIONS.SET_APP_STATE,
      payload: { state: APP_STATE.FAILED },
    });
  }
}

export function* updateApplicationAction({
  payload,
  success,
}: {
  type: typeof ACTIONS.UPDATE_APPLICATION_ACTION;
  payload: { applicationId: string; update: any };
  success?: () => void;
}) {
  try {
    yield put({
      type: ACTIONS.SET_APP_STATE,
      payload: { state: APP_STATE.LOADING },
    });

    const data: { success: boolean } = yield call(
      CommonAPI.updateApplicationAction,
      payload
    );

    if (data.success) {
      yield call(getJobs, { type: ACTIONS.GET_JOBS });
    }

    yield put({
      type: ACTIONS.SET_APP_STATE,
      payload: { state: APP_STATE.SUCCESS },
    });
    success?.();
  } catch (error) {
    success?.();
    yield put({
      type: ACTIONS.SET_APP_STATE,
      payload: { state: APP_STATE.FAILED },
    });
  }
}

export default function* applicationSaga() {
  yield takeLeading(ACTIONS.CREATE_MEETING, createMeeting);
  yield takeLeading(ACTIONS.END_MEETING, endMeeting);
  yield takeLeading(ACTIONS.UPDATE_APPLICATION, updateApplication);
  yield takeLeading(ACTIONS.UPDATE_APPLICATION_ACTION, updateApplicationAction);
}
