import React from "react";
import { ApplicationStatus } from "../common/types";

type OwnProps = {
  selected?: string;
  onSelect: (tab: string) => void;
  selectedStatus?: ApplicationStatus;
};

type TabType = { tab: string; status: ApplicationStatus; disabled: boolean };

const getTabs = (status?: ApplicationStatus): TabType[] => {
  if (status === "Pending") {
    return [
      { tab: "Candidate", status: "Pending", disabled: false },
      { tab: "Interview", status: "In progress", disabled: true },
      { tab: "Analyse", status: "Analyse", disabled: true },
    ];
  } else if (status === "In progress") {
    return [
      { tab: "Candidate", status: "Pending", disabled: false },
      { tab: "Interview", status: "In progress", disabled: false },
      { tab: "Analyse", status: "Analyse", disabled: true },
    ];
  } else {
    return [
      { tab: "Candidate", status: "Pending", disabled: false },
      { tab: "Interview", status: "In progress", disabled: false },
      { tab: "Analyse", status: "Analyse", disabled: false },
    ];
  }
};

const TabNavBar = ({ selected, onSelect, selectedStatus }: OwnProps) => {
  const renderTabs = ({ tab, disabled }: TabType, index: number) => {
    const className = tab === selected ? "nav-link active" : "nav-link";
    const onClick = () => onSelect(tab);
    return (
      <li className="nav-item" key={index}>
        <button
          className={className}
          aria-current="page"
          onClick={onClick}
          disabled={disabled}
        >
          {tab}
        </button>
      </li>
    );
  };
  return (
    <ul className="nav nav-tabs mb-4">
      {getTabs(selectedStatus).map(renderTabs)}
    </ul>
  );
};

export default TabNavBar;
